@@ -30,15 +30,14 @@
 #include <gtk/gtk.h>
 #include <canberra-gtk.h>
 
-#include <libgames-support/games-gridframe.h>
-#include <libgames-support/games-stock.h>
-#include <libgames-support/games-fullscreen-action.h>
-
 #include "connect4.h"
 #include "main.h"
 #include "theme.h"
 #include "prefs.h"
 #include "gfx.h"
+#include "games-gridframe.h"
+#include "games-fullscreen-action.h"
+#include "games-stock.h"
 
 #define SPEED_MOVE     25
 #define SPEED_DROP     20
