@@ -27,11 +27,8 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <libgames-support/games-controls.h>
-#include <libgames-support/games-file-list.h>
 #include <libgames-support/games-scores.h>
 #include <libgames-support/games-scores-dialog.h>
-#include <libgames-support/games-settings.h>
 
 #include "properties.h"
 #include "gameconfig.h"
@@ -41,6 +38,8 @@
 #include "keyboard.h"
 #include "game.h"
 #include "menu.h"
+#include "games-file-list.h"
+#include "games-controls.h"
 
 
 /**********************************************************************/
