@@ -29,14 +29,14 @@
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <libgames-support/games-gridframe.h>
-#include <libgames-support/games-preimage.h>
 #include <libgames-support/games-scores.h>
 #include <libgames-support/games-scores-dialog.h>
-#include <libgames-support/games-stock.h>
-#include <libgames-support/games-fullscreen-action.h>
 
 #include "pieces.h"
+#include "games-preimage.h"
+#include "games-gridframe.h"
+#include "games-fullscreen-action.h"
+#include "games-stock.h"
 
 #define APPNAME "gnotski"
 #define APPNAME_LONG N_("Klotski")
